@@ -1,6 +1,6 @@
 package Module::Build::Tiny;
 {
-  $Module::Build::Tiny::VERSION = '0.012';
+  $Module::Build::Tiny::VERSION = '0.013';
 }
 use strict;
 use warnings;
@@ -15,6 +15,7 @@ use ExtUtils::Install qw/pm_to_blib install/;
 use ExtUtils::InstallPaths 0.002;
 use File::Basename qw/dirname/;
 use File::Find::Rule qw/find/;
+use File::HomeDir;
 use File::Path qw/mkpath/;
 use File::Slurp qw/read_file write_file/;
 use File::Spec::Functions qw/catfile catdir rel2abs/;
@@ -22,12 +23,16 @@ use Getopt::Long qw/GetOptions/;
 use JSON 2 qw/encode_json decode_json/;
 use TAP::Harness;
 
-sub _get_meta {
+sub get_meta {
 	my ($metafile) = grep { -e $_ } qw/META.json META.yml/ or die "No META information provided\n";
 	return CPAN::Meta->load_file($metafile);
 }
 
-sub _manify {
+sub detildefy {
+	$_[0] =~ s{ \A ~ ([^/]*) }{ length $1 ? File::HomeDir->users_home($1) : File::HomeDir->my_home }xe;
+}
+
+sub manify {
 	my ($input_file, $output_file, $section, $opts) = @_;
 	my $dirname = dirname($output_file);
 	mkpath($dirname, $opts->{verbose}) if not -d $dirname;
@@ -46,8 +51,8 @@ my %actions = (
 		make_executable($_) for values %scripts;
 
 		if ($opt{install_paths}->is_default_installable('libdoc')) {
-			_manify($_, catfile('blib', 'bindoc', man1_pagename($_)), 1, \%opt) for keys %scripts;
-			_manify($_, catfile('blib', 'libdoc', man3_pagename($_)), 3, \%opt) for keys %modules;
+			manify($_, catfile('blib', 'bindoc', man1_pagename($_)), 1, \%opt) for keys %scripts;
+			manify($_, catfile('blib', 'libdoc', man3_pagename($_)), 3, \%opt) for keys %modules;
 		}
 	},
 	test => sub {
@@ -71,18 +76,19 @@ sub Build {
 	my @env = defined $ENV{PERL_MB_OPT} ? split_like_shell($ENV{PERL_MB_OPT}) : ();
 	unshift @ARGV, map { @{$_} } grep { defined } $rc_opts->{'*'}, $bpl, $rc_opts->{$action}, \@env;
 	GetOptions(\my %opt, qw/install_base=s install_path=s% installdirs=s destdir=s prefix=s config=s% uninst:1 verbose:1 dry_run:1/);
-	@opt{'config', 'meta'} = (ExtUtils::Config->new($opt{config}), _get_meta());
+	detildefy($_) for grep { defined } @opt{qw/install_base destdir prefix/}, values %{ $opt{install_path} };
+	@opt{'config', 'meta'} = (ExtUtils::Config->new($opt{config}), get_meta());
 	$actions{$action}->(%opt, install_paths => ExtUtils::InstallPaths->new(%opt, dist_name => $opt{meta}->name));
 }
 
 sub Build_PL {
-	my $meta = _get_meta();
+	my $meta = get_meta();
 	printf "Creating new 'Build' script for '%s' version '%s'\n", $meta->name, $meta->version;
 	my $dir = $meta->name eq 'Module-Build-Tiny' ? 'lib' : 'inc';
 	write_file('Build', "#!perl\nuse lib '$dir';\nuse Module::Build::Tiny;\nBuild();\n");
 	make_executable('Build');
 	write_file(qw/_build_params/, encode_json(\@ARGV));
-	write_file("MY$_", read_file($_)) for grep { -f } qw/META.json META.yml/;
+	$meta->save(@$_) for ['MYMETA.json'], ['MYMETA.yml' => { version => 1.4 }];
 }
 
 1;
@@ -90,7 +96,9 @@ sub Build_PL {
 #ABSTRACT: A tiny replacement for Module::Build
 
 
+# vi:et:sts=2:sw=2:ts=2
 
+__END__
 =pod
 
 =head1 NAME
@@ -99,7 +107,7 @@ Module::Build::Tiny - A tiny replacement for Module::Build
 
 =head1 VERSION
 
-version 0.012
+version 0.013
 
 =head1 SYNOPSIS
 
@@ -194,9 +202,6 @@ environment variable the same way they can with Module::Build.
 
 L<Module::Build>
 
-=for Pod::Coverage Build_PL
-=end
-
 =head1 AUTHORS
 
 =over 4
@@ -220,8 +225,3 @@ the same terms as the Perl 5 programming language system itself.
 
 =cut
 
-
-__END__
-
-
-# vi:et:sts=2:sw=2:ts=2
